<!--
    =====================================
    generator=datazen
    version=1.1.0
    hash=e02ba7057bfec593a50efee69c45ac3f
    =====================================
-->

# datazen

![Python package](https://github.com/vkottler/datazen/workflows/Python%20package/badge.svg)

Compile and render schema-validated configuration data.
